pub enum ExecError {
Show 26 variants
Structured(StructuredError),
IncompleteTemplate(String),
IOError(Error),
UnknownNode(Nodes),
ExpectedIfOrWith(Nodes),
Utf8ConversionFailed(FromUtf8Error),
EmptyStack,
VarContextToSmall(usize),
InvalidRange(Value),
PipelineMustYieldString,
TemplateNotDefined(String),
MaxTemplateDepth,
ErrorEvaluatingPipe(PipeNode),
NoArgsForCommandNode(CommandNode),
CannotEvaluateCommand(Nodes),
FieldChainWithoutFields,
NotAFunctionButArguments(String),
NoFieldsInEvalChainNode,
NullInChain(ChainNode),
InvalidArgument(Nodes),
UndefinedFunction(String),
FuncError(FuncError),
ArgumentForNonFunction(Nodes),
OnlyMapsAndObjectsHaveFields,
NoFieldFor(String, Value),
VariableNotFound(String),
}Variants
Structured(StructuredError)
IncompleteTemplate(String)
IOError(Error)
UnknownNode(Nodes)
ExpectedIfOrWith(Nodes)
Utf8ConversionFailed(FromUtf8Error)
EmptyStack
VarContextToSmall(usize)
InvalidRange(Value)
PipelineMustYieldString
TemplateNotDefined(String)
MaxTemplateDepth
ErrorEvaluatingPipe(PipeNode)
NoArgsForCommandNode(CommandNode)
CannotEvaluateCommand(Nodes)
FieldChainWithoutFields
NotAFunctionButArguments(String)
NoFieldsInEvalChainNode
NullInChain(ChainNode)
InvalidArgument(Nodes)
UndefinedFunction(String)
FuncError(FuncError)
ArgumentForNonFunction(Nodes)
OnlyMapsAndObjectsHaveFields
NoFieldFor(String, Value)
VariableNotFound(String)
Implementations
Sourceimpl ExecError
impl ExecError
Sourcepub fn with_context(
name: impl ToString,
line: usize,
col: usize,
len: usize,
error: ExecError,
) -> Self
pub fn with_context( name: impl ToString, line: usize, col: usize, len: usize, error: ExecError, ) -> Self
Wrap an error with location context, preserving the error chain. The innermost (original) error location stays as primary, outer contexts are added to the cause chain.
Sourcepub fn as_structured(&self) -> Option<&StructuredError>
pub fn as_structured(&self) -> Option<&StructuredError>
Get the structured error if this is one